@@ -61,11 +61,11 @@ htmlGetMetaEncoding(htmlDocPtr doc) {
      */
     while (cur != NULL) {
 	if (cur->name != NULL) {
-	    if (!xmlStrcmp(cur->name, BAD_CAST"html"))
+	    if (xmlStrEqual(cur->name, BAD_CAST"html"))
 		break;
-	    if (!xmlStrcmp(cur->name, BAD_CAST"head"))
+	    if (xmlStrEqual(cur->name, BAD_CAST"head"))
 		goto found_head;
-	    if (!xmlStrcmp(cur->name, BAD_CAST"meta"))
+	    if (xmlStrEqual(cur->name, BAD_CAST"meta"))
 		goto found_meta;
 	}
 	cur = cur->next;
@@ -79,9 +79,9 @@ htmlGetMetaEncoding(htmlDocPtr doc) {
      */
     while (cur != NULL) {
 	if (cur->name != NULL) {
-	    if (!xmlStrcmp(cur->name, BAD_CAST"head"))
+	    if (xmlStrEqual(cur->name, BAD_CAST"head"))
 		break;
-	    if (!xmlStrcmp(cur->name, BAD_CAST"meta"))
+	    if (xmlStrEqual(cur->name, BAD_CAST"meta"))
 		goto found_meta;
 	}
 	cur = cur->next;
@@ -97,7 +97,7 @@ found_head:
 found_meta:
     while (cur != NULL) {
 	if (cur->name != NULL) {
-	    if (!xmlStrcmp(cur->name, BAD_CAST"meta")) {
+	    if (xmlStrEqual(cur->name, BAD_CAST"meta")) {
 		xmlAttrPtr attr = cur->properties;
 		int http;
 		const xmlChar *value;
@@ -113,17 +113,11 @@ found_meta:
 #else
 			value = xmlBufferContent(attr->children->content);
 #endif
-			if (((!xmlStrcmp(attr->name, BAD_CAST"http-equiv")) ||
-			     (!xmlStrcmp(attr->name, BAD_CAST"Http-Equiv")) ||
-			     (!xmlStrcmp(attr->name, BAD_CAST"HTTP-EQUIV"))) &&
-			    ((!xmlStrcmp(value, BAD_CAST"Content-Type")) ||
-			     (!xmlStrcmp(value, BAD_CAST"content-type")) ||
-			     (!xmlStrcmp(value, BAD_CAST"CONTENT-TYPE"))))
+			if ((!xmlStrcasecmp(attr->name, BAD_CAST"http-equiv"))
+			 && (!xmlStrcasecmp(value, BAD_CAST"Content-Type")))
 			    http = 1;
-			else if ((value != NULL) &&
-				 ((!xmlStrcmp(attr->name, BAD_CAST"content")) ||
-				  (!xmlStrcmp(attr->name, BAD_CAST"Content")) ||
-				  (!xmlStrcmp(attr->name, BAD_CAST"CONTENT"))))
+			else if ((value != NULL)
+			 && (!xmlStrcasecmp(attr->name, BAD_CAST"content")))
 			    content = value;
 			if ((http != 0) && (content != NULL))
 			    goto found_content;
@@ -197,9 +191,9 @@ htmlSetMetaEncoding(htmlDocPtr doc, const xmlChar *encoding) {
      */
     while (cur != NULL) {
 	if (cur->name != NULL) {
-	    if (!xmlStrcmp(cur->name, BAD_CAST"html"))
+	    if (xmlStrEqual(cur->name, BAD_CAST"html"))
 		break;
-	    if (!xmlStrcmp(cur->name, BAD_CAST"body")) {
+	    if (xmlStrEqual(cur->name, BAD_CAST"body")) {
 		if (encoding == NULL)
 		    return(0);
 		meta = xmlNewDocNode(doc, NULL, BAD_CAST"head", NULL);
@@ -211,9 +205,9 @@ htmlSetMetaEncoding(htmlDocPtr doc, const xmlChar *encoding) {
 		xmlNewProp(meta, BAD_CAST"content", BAD_CAST newcontent);
 		return(0);
 	    }
-	    if (!xmlStrcmp(cur->name, BAD_CAST"head"))
+	    if (xmlStrEqual(cur->name, BAD_CAST"head"))
 		goto found_head;
-	    if (!xmlStrcmp(cur->name, BAD_CAST"meta"))
+	    if (xmlStrEqual(cur->name, BAD_CAST"meta"))
 		goto found_meta;
 	}
 	cur = cur->next;
@@ -227,9 +221,9 @@ htmlSetMetaEncoding(htmlDocPtr doc, const xmlChar *encoding) {
      */
     while (cur != NULL) {
 	if (cur->name != NULL) {
-	    if (!xmlStrcmp(cur->name, BAD_CAST"head"))
+	    if (xmlStrEqual(cur->name, BAD_CAST"head"))
 		break;
-	    if (!xmlStrcmp(cur->name, BAD_CAST"body")) {
+	    if (xmlStrEqual(cur->name, BAD_CAST"body")) {
 		if (encoding == NULL)
 		    return(0);
 		meta = xmlNewDocNode(doc, NULL, BAD_CAST"head", NULL);
@@ -241,7 +235,7 @@ htmlSetMetaEncoding(htmlDocPtr doc, const xmlChar *encoding) {
 		xmlNewProp(meta, BAD_CAST"content", BAD_CAST newcontent);
 		return(0);
 	    }
-	    if (!xmlStrcmp(cur->name, BAD_CAST"meta"))
+	    if (xmlStrEqual(cur->name, BAD_CAST"meta"))
 		goto found_meta;
 	}
 	cur = cur->next;
@@ -278,7 +272,7 @@ found_meta:
      */
     while (cur != NULL) {
 	if (cur->name != NULL) {
-	    if (!xmlStrcmp(cur->name, BAD_CAST"meta")) {
+	    if (xmlStrEqual(cur->name, BAD_CAST"meta")) {
 		xmlAttrPtr attr = cur->properties;
 		int http;
 		const xmlChar *value;
@@ -294,17 +288,11 @@ found_meta:
 #else
 			value = xmlBufferContent(attr->children->content);
 #endif
-			if (((!xmlStrcmp(attr->name, BAD_CAST"http-equiv")) ||
-			     (!xmlStrcmp(attr->name, BAD_CAST"Http-Equiv")) ||
-			     (!xmlStrcmp(attr->name, BAD_CAST"HTTP-EQUIV"))) &&
-			    ((!xmlStrcmp(value, BAD_CAST"Content-Type")) ||
-			     (!xmlStrcmp(value, BAD_CAST"content-type")) ||
-			     (!xmlStrcmp(value, BAD_CAST"CONTENT-TYPE"))))
+			if ((!xmlStrcasecmp(attr->name, BAD_CAST"http-equiv"))
+			 && (!xmlStrcasecmp(value, BAD_CAST"Content-Type")))
 			    http = 1;
-			else if ((value != NULL) &&
-				 ((!xmlStrcmp(attr->name, BAD_CAST"content")) ||
-				  (!xmlStrcmp(attr->name, BAD_CAST"Content")) ||
-				  (!xmlStrcmp(attr->name, BAD_CAST"CONTENT"))))
+			else if ((value != NULL)
+			 && (!xmlStrcasecmp(attr->name, BAD_CAST"content")))
 			    content = value;
 			if ((http != 0) && (content != NULL))
 			    break;
