@@ -1491,14 +1491,14 @@ xmlShellPwd(xmlShellCtxtPtr ctxt, char *buffer, xmlNodePtr node,
 	     */
 	    tmp = cur->prev;
             while (tmp != NULL) {
-	        if (!xmlStrcmp(cur->name, tmp->name))
+	        if (xmlStrEqual(cur->name, tmp->name))
 		    occur++;
 	        tmp = tmp->prev;
 	    }
 	    if (occur == 0) {
 	        tmp = cur->next;
 		while (tmp != NULL) {
-		    if (!xmlStrcmp(cur->name, tmp->name))
+		    if (xmlStrEqual(cur->name, tmp->name))
 			occur++;
 		    tmp = tmp->next;
 		}
@@ -1596,7 +1596,7 @@ xmlShell(xmlDocPtr doc, char *filename, xmlShellReadlineFunc input,
 #ifdef HAVE_SNPRINTF
 	    snprintf(prompt, sizeof(prompt), "%s > ", ctxt->node->name);
 #else
-	    sprintf(buf, "%s > ", ctxt->node->name);
+	    sprintf(prompt, "%s > ", ctxt->node->name);
 #endif
         else
 	    sprintf(prompt, "? > ");
