@@ -254,26 +254,11 @@ xmlSaveUri(xmlURIPtr uri) {
 	        ((*(p) == '+')) || ((*(p) == '$')) || ((*(p) == ',')))
 		ret[len++] = *p++;
 	    else {
-		int val = *p++;
+		int val = *(unsigned char *)p++;
+		int hi = val / 0x10, lo = val % 0x10;
 		ret[len++] = '%';
-		switch (val / 0x10) {
-		    case 0xF: ret[len++] = 'F'; break;
-		    case 0xE: ret[len++] = 'E'; break;
-		    case 0xD: ret[len++] = 'D'; break;
-		    case 0xC: ret[len++] = 'C'; break;
-		    case 0xB: ret[len++] = 'B'; break;
-		    case 0xA: ret[len++] = 'A'; break;
-		    default: ret[len++] = '0' + (val / 0x10);
-		}
-		switch (val % 0x10) {
-		    case 0xF: ret[len++] = 'F'; break;
-		    case 0xE: ret[len++] = 'E'; break;
-		    case 0xD: ret[len++] = 'D'; break;
-		    case 0xC: ret[len++] = 'C'; break;
-		    case 0xB: ret[len++] = 'B'; break;
-		    case 0xA: ret[len++] = 'A'; break;
-		    default: ret[len++] = '0' + (val % 0x10);
-		}
+		ret[len++] = hi + (hi > 9? 'A'-10 : '0');
+		ret[len++] = lo + (lo > 9? 'A'-10 : '0');
 	    }
 	}
 	if (len >= max) {
@@ -314,26 +299,11 @@ xmlSaveUri(xmlURIPtr uri) {
 			((*(p) == ',')))
 			ret[len++] = *p++;
 		    else {
-			int val = *p++;
+			int val = *(unsigned char *)p++;
+			int hi = val / 0x10, lo = val % 0x10;
 			ret[len++] = '%';
-			switch (val / 0x10) {
-			    case 0xF: ret[len++] = 'F'; break;
-			    case 0xE: ret[len++] = 'E'; break;
-			    case 0xD: ret[len++] = 'D'; break;
-			    case 0xC: ret[len++] = 'C'; break;
-			    case 0xB: ret[len++] = 'B'; break;
-			    case 0xA: ret[len++] = 'A'; break;
-			    default: ret[len++] = '0' + (val / 0x10);
-			}
-			switch (val % 0x10) {
-			    case 0xF: ret[len++] = 'F'; break;
-			    case 0xE: ret[len++] = 'E'; break;
-			    case 0xD: ret[len++] = 'D'; break;
-			    case 0xC: ret[len++] = 'C'; break;
-			    case 0xB: ret[len++] = 'B'; break;
-			    case 0xA: ret[len++] = 'A'; break;
-			    default: ret[len++] = '0' + (val % 0x10);
-			}
+			ret[len++] = hi + (hi > 9? 'A'-10 : '0');
+			ret[len++] = lo + (lo > 9? 'A'-10 : '0');
 		    }
 		}
 		if (len + 3 >= max) {
@@ -396,26 +366,11 @@ xmlSaveUri(xmlURIPtr uri) {
                     ((*(p) == '=')) || ((*(p) == '+')))
 		    ret[len++] = *p++;
 		else {
-		    int val = *p++;
+		    int val = *(unsigned char *)p++;
+		    int hi = val / 0x10, lo = val % 0x10;
 		    ret[len++] = '%';
-		    switch (val / 0x10) {
-			case 0xF: ret[len++] = 'F'; break;
-			case 0xE: ret[len++] = 'E'; break;
-			case 0xD: ret[len++] = 'D'; break;
-			case 0xC: ret[len++] = 'C'; break;
-			case 0xB: ret[len++] = 'B'; break;
-			case 0xA: ret[len++] = 'A'; break;
-			default: ret[len++] = '0' + (val / 0x10);
-		    }
-		    switch (val % 0x10) {
-			case 0xF: ret[len++] = 'F'; break;
-			case 0xE: ret[len++] = 'E'; break;
-			case 0xD: ret[len++] = 'D'; break;
-			case 0xC: ret[len++] = 'C'; break;
-			case 0xB: ret[len++] = 'B'; break;
-			case 0xA: ret[len++] = 'A'; break;
-			default: ret[len++] = '0' + (val % 0x10);
-		    }
+		    ret[len++] = hi + (hi > 9? 'A'-10 : '0');
+		    ret[len++] = lo + (lo > 9? 'A'-10 : '0');
 		}
 	    }
 	}
@@ -436,26 +391,11 @@ xmlSaveUri(xmlURIPtr uri) {
 	            ((*(p) == ',')))
 		    ret[len++] = *p++;
 		else {
-		    int val = *p++;
+		    int val = *(unsigned char *)p++;
+		    int hi = val / 0x10, lo = val % 0x10;
 		    ret[len++] = '%';
-		    switch (val / 0x10) {
-			case 0xF: ret[len++] = 'F'; break;
-			case 0xE: ret[len++] = 'E'; break;
-			case 0xD: ret[len++] = 'D'; break;
-			case 0xC: ret[len++] = 'C'; break;
-			case 0xB: ret[len++] = 'B'; break;
-			case 0xA: ret[len++] = 'A'; break;
-			default: ret[len++] = '0' + (val / 0x10);
-		    }
-		    switch (val % 0x10) {
-			case 0xF: ret[len++] = 'F'; break;
-			case 0xE: ret[len++] = 'E'; break;
-			case 0xD: ret[len++] = 'D'; break;
-			case 0xC: ret[len++] = 'C'; break;
-			case 0xB: ret[len++] = 'B'; break;
-			case 0xA: ret[len++] = 'A'; break;
-			default: ret[len++] = '0' + (val % 0x10);
-		    }
+		    ret[len++] = hi + (hi > 9? 'A'-10 : '0');
+		    ret[len++] = lo + (lo > 9? 'A'-10 : '0');
 		}
 	    }
 	}
@@ -482,26 +422,11 @@ xmlSaveUri(xmlURIPtr uri) {
 		if ((IS_UNRESERVED(*(p))) || (IS_RESERVED(*(p)))) 
 		    ret[len++] = *p++;
 		else {
-		    int val = *p++;
+		    int val = *(unsigned char *)p++;
+		    int hi = val / 0x10, lo = val % 0x10;
 		    ret[len++] = '%';
-		    switch (val / 0x10) {
-			case 0xF: ret[len++] = 'F'; break;
-			case 0xE: ret[len++] = 'E'; break;
-			case 0xD: ret[len++] = 'D'; break;
-			case 0xC: ret[len++] = 'C'; break;
-			case 0xB: ret[len++] = 'B'; break;
-			case 0xA: ret[len++] = 'A'; break;
-			default: ret[len++] = '0' + (val / 0x10);
-		    }
-		    switch (val % 0x10) {
-			case 0xF: ret[len++] = 'F'; break;
-			case 0xE: ret[len++] = 'E'; break;
-			case 0xD: ret[len++] = 'D'; break;
-			case 0xC: ret[len++] = 'C'; break;
-			case 0xB: ret[len++] = 'B'; break;
-			case 0xA: ret[len++] = 'A'; break;
-			default: ret[len++] = '0' + (val % 0x10);
-		    }
+		    ret[len++] = hi + (hi > 9? 'A'-10 : '0');
+		    ret[len++] = lo + (lo > 9? 'A'-10 : '0');
 		}
 	    }
 	}
@@ -528,26 +453,11 @@ xmlSaveUri(xmlURIPtr uri) {
 		if ((IS_UNRESERVED(*(p))) || (IS_RESERVED(*(p)))) 
 		    ret[len++] = *p++;
 		else {
-		    int val = *p++;
+		    int val = *(unsigned char *)p++;
+		    int hi = val / 0x10, lo = val % 0x10;
 		    ret[len++] = '%';
-		    switch (val / 0x10) {
-			case 0xF: ret[len++] = 'F'; break;
-			case 0xE: ret[len++] = 'E'; break;
-			case 0xD: ret[len++] = 'D'; break;
-			case 0xC: ret[len++] = 'C'; break;
-			case 0xB: ret[len++] = 'B'; break;
-			case 0xA: ret[len++] = 'A'; break;
-			default: ret[len++] = '0' + (val / 0x10);
-		    }
-		    switch (val % 0x10) {
-			case 0xF: ret[len++] = 'F'; break;
-			case 0xE: ret[len++] = 'E'; break;
-			case 0xD: ret[len++] = 'D'; break;
-			case 0xC: ret[len++] = 'C'; break;
-			case 0xB: ret[len++] = 'B'; break;
-			case 0xA: ret[len++] = 'A'; break;
-			default: ret[len++] = '0' + (val % 0x10);
-		    }
+		    ret[len++] = hi + (hi > 9? 'A'-10 : '0');
+		    ret[len++] = lo + (lo > 9? 'A'-10 : '0');
 		}
 	    }
 	}
@@ -1462,16 +1372,11 @@ xmlNormalizeURIPath(char *path) {
 xmlChar *
 xmlBuildURI(const xmlChar *URI, const xmlChar *base) {
     xmlChar *val = NULL;
-    int ret, len, index, cur, out;
+    int ret, ret2, len, index, cur, out;
     xmlURIPtr ref = NULL;
     xmlURIPtr bas = NULL;
     xmlURIPtr res = NULL;
 
-    if ((URI == NULL) && (base == NULL))
-	return(NULL);
-    if (URI == NULL)
-	return((xmlChar *) xmlMemStrdup((const char *) base));
-
     /*
      * 1) The URI reference is parsed into the potential four components and
      *    fragment identifier, as described in Section 4.3.
@@ -1480,20 +1385,43 @@ xmlBuildURI(const xmlChar *URI, const xmlChar *base) {
      *    as a reference to "." rather than as a synonym for the current
      *    URI.  Should we do that here?
      */
-    ref = xmlCreateURI();
-    if (ref == NULL)
-	goto done;
-    if (*URI) {
-	ret = xmlParseURIReference(ref, (const char *) URI);
-	if (ret != 0)
+    if (URI == NULL) 
+	ret = -1;
+    else {
+	ref = xmlCreateURI();
+	if (ref == NULL)
 	    goto done;
+	if (*URI)
+	    ret = xmlParseURIReference(ref, (const char *) URI);
+	else
+	    ret = -1;
     }
-    bas = xmlCreateURI();
-    if (bas == NULL)
+    if (base == NULL)
+	ret2 = -1;
+    else {
+	bas = xmlCreateURI();
+	if (bas == NULL)
+	    goto done;
+	ret2 = xmlParseURIReference(bas, (const char *) base);
+    }
+    if ((ret != 0) && (ret2 != 0))
 	goto done;
-    ret = xmlParseURIReference(bas, (const char *) base);
-    if (ret != 0)
+    if (ret != 0) {
+	/*
+	 * the base fragment must be ignored
+	 */
+	if (bas->fragment != NULL) {
+	    xmlFree(bas->fragment);
+	    bas->fragment = NULL;
+	}
+	val = xmlSaveUri(bas);
 	goto done;
+    }
+    if (ret2 != 0) {
+	val = xmlSaveUri(ref);
+	goto done;
+    }
+
 
     /*
      * 2) If the path component is empty and the scheme, authority, and
@@ -1637,15 +1565,13 @@ xmlBuildURI(const xmlChar *URI, const xmlChar *base) {
      * b) The reference's path component is appended to the buffer
      *    string.
      */
-    if (ref->path != NULL) {
+    if (ref->path != NULL && ref->path[0] != 0) {
 	index = 0;
 	/*
 	 * Ensure the path includes a '/'
 	 */
-	if ((out >0) && (res->path[out -1] != '/') &&
-	    (ref->path[0] != 0) && (ref->path[index] != '/')) {
+	if ((out == 0) && (bas->server != NULL))
 	    res->path[out++] = '/';
-	}
 	while (ref->path[index] != 0) {
 	    res->path[out++] = ref->path[index++];
 	}
